@@ -13,6 +13,7 @@ from botocore.discovery import block_endpoint_discovery_required_operations
 from botocore.exceptions import OperationNotPageableError, UnknownServiceError
 from botocore.history import get_global_history_recorder
 from botocore.hooks import first_non_none_response
+from botocore.useragent import register_feature_id
 from botocore.utils import get_service_module_name
 from botocore.waiter import xform_name
 
@@ -80,7 +81,11 @@ class AioClientCreator(ClientCreator):
             config_store=self._config_store,
             service_signature_version=service_signature_version,
         )
-        client_args = self._get_client_args(
+        if token := self._evaluate_client_specific_token(
+            service_model.signing_name
+        ):
+            auth_token = token
+        client_args = await self._get_client_args(
             service_model,
             region_name,
             is_secure,
@@ -157,6 +162,9 @@ class AioClientCreator(ClientCreator):
             self._register_v2_adaptive_retries(client)
         elif retry_mode == 'legacy':
             self._register_legacy_retries(client)
+        else:
+            return
+        register_feature_id(f'RETRY_MODE_{retry_mode.upper()}')
 
     def _register_v2_standard_retries(self, client):
         max_attempts = client.meta.config.retries.get('total_max_attempts')
@@ -264,7 +272,7 @@ class AioClientCreator(ClientCreator):
             'before-parameter-build.s3', self._inject_s3_input_parameters
         )
 
-    def _get_client_args(
+    async def _get_client_args(
         self,
         service_model,
         region_name,
@@ -290,7 +298,7 @@ class AioClientCreator(ClientCreator):
             config_store=self._config_store,
             user_agent_creator=self._user_agent_creator,
         )
-        return args_creator.get_client_args(
+        return await args_creator.get_client_args(
             service_model,
             region_name,
             is_secure,
@@ -351,6 +359,7 @@ class AioBaseClient(BaseClient):
             'has_streaming_input': operation_model.has_streaming_input,
             'auth_type': operation_model.resolved_auth_type,
             'unsigned_payload': operation_model.unsigned_payload,
+            'auth_options': self._service_model.metadata.get('auth'),
         }
 
         api_params = await self._emit_api_params(
@@ -408,9 +417,9 @@ class AioBaseClient(BaseClient):
 
         if http.status_code >= 300:
             error_info = parsed_response.get("Error", {})
-            error_code = error_info.get("QueryErrorCode") or error_info.get(
-                "Code"
-            )
+            error_code = request_context.get(
+                'error_code_override'
+            ) or error_info.get("Code")
             error_class = self.exceptions.from_code(error_code)
             raise error_class(parsed_response, operation_name)
         else:
